@@ -19,7 +19,6 @@
  */
  
 #include <opensync/opensync.h>
-#include <opensync/opensync-support.h>
 #include <opensync/opensync-serializer.h>
 #include <opensync/opensync-format.h>
 #include <glib.h>
@@ -34,7 +33,7 @@
  * osync_env_format_set_like().
  */
 
-static OSyncConvCmpResult compare_vevent(const char *leftdata, unsigned int leftsize, const char *rightdata, unsigned int rightsize)
+static OSyncConvCmpResult compare_vevent(const char *leftdata, unsigned int leftsize, const char *rightdata, unsigned int rightsize, void *user_data, OSyncError **error)
 {
 	/* Consider empty block equal NULL pointers */
 	if (!leftsize) leftdata = NULL;
@@ -53,7 +52,7 @@ static OSyncConvCmpResult compare_vevent(const char *leftdata, unsigned int left
 	return OSYNC_CONV_DATA_MISMATCH;
 }
 
-static osync_bool detect_plain_as_vevent10(const char *data, int size, void *userdata)
+static osync_bool detect_plain_as_vevent10(const char *data, int size, void *user_data)
 {
 	osync_trace(TRACE_INTERNAL, "start: %s", __func__);
 
@@ -63,7 +62,7 @@ static osync_bool detect_plain_as_vevent10(const char *data, int size, void *use
 	return g_pattern_match_simple("*BEGIN:VCALENDAR*VERSION:1.0*BEGIN:VEVENT*", data);
 }
 
-static osync_bool detect_plain_as_vevent20(const char *data, int size, void *userdata)
+static osync_bool detect_plain_as_vevent20(const char *data, int size, void *user_data)
 {
 	osync_trace(TRACE_INTERNAL, "start: %s", __func__);
 
@@ -73,34 +72,23 @@ static osync_bool detect_plain_as_vevent20(const char *data, int size, void *use
 	return g_pattern_match_simple("*BEGIN:VCALENDAR*VERSION:2.0*BEGIN:VEVENT*", data);
 }
 
-static void create_vevent10(char **data, unsigned int *size)
-{
-	*data = g_strdup_printf("BEGIN:VCALENDAR\r\nPRODID:-//OpenSync//NONSGML OpenSync TestGenerator//EN\r\nVERSION:1.0\r\nBEGIN:VEVENT\r\nDTSTART:20050307T124500Z\r\nDTEND:20050307T130000Z\r\nSEQUENCE:0\r\nSUMMARY:%s\r\nEND:VEVENT\r\nEND:VCALENDAR", osync_rand_str(20));
-	*size = strlen(*data);
-}
-
-static void create_vevent20(char **data, unsigned int *size)
-{
-	*data = g_strdup_printf("BEGIN:VCALENDAR\r\nPRODID:-//OpenSync//NONSGML OpenSync TestGenerator//EN\r\nVERSION:2.0\r\nBEGIN:VEVENT\r\nDTSTART:20050307T124500Z\r\nDTEND:20050307T130000Z\r\nSEQUENCE:0\r\nSUMMARY:%s\r\nEND:VEVENT\r\nEND:VCALENDAR", osync_rand_str(20));
-	*size = strlen(*data);
-}
-
-static void destroy_vevent(char *input, unsigned int inpsize)
+static osync_bool destroy_vevent(char *input, unsigned int inpsize, void *user_data, OSyncError **error)
 {
 	g_free(input);
+	return TRUE;
 }
 
 osync_bool get_format_info(OSyncFormatEnv *env, OSyncError **error)
 {
 	OSyncObjFormat *format = osync_objformat_new("vevent10", "event", error);
 	if (!format)
-		return FALSE;
+		goto error;
 	
 	osync_objformat_set_compare_func(format, compare_vevent);
-	osync_objformat_set_create_func(format, create_vevent10);
 	osync_objformat_set_destroy_func(format, destroy_vevent);
 	
-	osync_format_env_register_objformat(env, format);
+	if (!osync_format_env_register_objformat(env, format, error))
+		goto error;
 	osync_objformat_unref(format);
 	
 	
@@ -109,10 +97,11 @@ osync_bool get_format_info(OSyncFormatEnv *env, OSyncError **error)
 		return FALSE;
 	
 	osync_objformat_set_compare_func(format, compare_vevent);
-	osync_objformat_set_create_func(format, create_vevent20);
 	osync_objformat_set_destroy_func(format, destroy_vevent);
 	
-	osync_format_env_register_objformat(env, format);
+	if (!osync_format_env_register_objformat(env, format, error))
+		goto error;
+
 	osync_objformat_unref(format);
 	
 	
@@ -133,6 +122,9 @@ osync_bool get_format_info(OSyncFormatEnv *env, OSyncError **error)
 	*/
 	
 	return TRUE;
+
+error:
+	return FALSE;
 }
 
 osync_bool get_conversion_info(OSyncFormatEnv *env, OSyncError **error)
@@ -158,13 +150,13 @@ osync_bool get_conversion_info(OSyncFormatEnv *env, OSyncError **error)
 	OSyncFormatConverter *conv = osync_converter_new_detector(plain, vevent10, detect_plain_as_vevent10, error);
 	if (!conv)
 		return FALSE;
-	osync_format_env_register_converter(env, conv);
+	osync_format_env_register_converter(env, conv, error);
 	osync_converter_unref(conv);
 	
 	conv = osync_converter_new_detector(plain, vevent20, detect_plain_as_vevent20, error);
 	if (!conv)
 		return FALSE;
-	osync_format_env_register_converter(env, conv);
+	osync_format_env_register_converter(env, conv, error);
 	osync_converter_unref(conv);
 	
 	return TRUE;
