@@ -259,7 +259,7 @@ static void _read_attribute_value_add (VFormatAttribute *attr, GString *str, GSt
 	if (charset) {
 
 		cd = iconv_open("UTF-8", charset->str);
-#if defined(SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(_WIN32)
                 if (iconv(cd, (const char**)&inbuf, &inbytesleft, &p, &outbytesleft) != (size_t)(-1)) {
 #else
                 if (iconv(cd, &inbuf, &inbytesleft, &p, &outbytesleft) != (size_t)(-1)) {
@@ -287,7 +287,7 @@ static void _read_attribute_value_add (VFormatAttribute *attr, GString *str, GSt
 
 			/* because inbuf is not UTF-8, we think it is ISO-8859-1 */
                         cd = iconv_open("UTF-8", "ISO-8859-1");
-#if defined(SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(SOLARIS) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(_WIN32)
                         if (iconv(cd, (const char**)&inbuf, &inbytesleft, &p, &outbytesleft) != (size_t)(-1)) {
 #else
                         if (iconv(cd, &inbuf, &inbytesleft, &p, &outbytesleft) != (size_t)(-1)) {
