@@ -1,7 +1,7 @@
 /*
  * xmlformat-vnote - convert vnote11 to xmlformat-note and backwards
  * Copyright (C) 2004-2005  Armin Bauer <armin.bauer@opensync.org>
- * Copyright (C) 2007  Daniel Gollub <dgollub@suse.de>
+ * Copyright (C) 2007  Daniel Gollub <gollub@b1-systems.de>
  * Copyright (C) 2007  Jerry Yu <jijun.yu@sun.com>
  * 
  * This library is free software; you can redistribute it and/or
@@ -71,17 +71,25 @@ osync_bool conv_vnote_to_xmlformat(char *input, unsigned int inpsize, char **out
 	*output = (char *)xmlformat;
 	*outpsize = osync_xmlformat_size();
 
-	osync_xmlformat_sort(xmlformat);
+	if (!osync_xmlformat_sort(xmlformat, error))
+		goto error;
 	
 	unsigned int size;
 	char *str;
-	osync_xmlformat_assemble(xmlformat, &str, &size);
+
+	if (!osync_xmlformat_assemble(xmlformat, &str, &size, error))
+		goto error;
+
 	osync_trace(TRACE_SENSITIVE, "... Output XMLFormat is: \n%s", str);
 	g_free(str);
 	
 	vformat_free(vnote);
 	osync_trace(TRACE_EXIT, "%s: TRUE", __func__);
 	return TRUE;
+
+error:
+	osync_trace(TRACE_EXIT, "%s: %s", __func__, osync_error_print(error));
+	return FALSE;
 }
 
 static VFormatAttribute *handle_xml_body_attribute(VFormat *vnote, OSyncXMLField *xmlfield, const char *encoding)
@@ -131,7 +139,10 @@ static osync_bool conv_xmlformat_to_vnotememo(char *input, unsigned int inpsize,
 	OSyncXMLFormat *xmlformat = (OSyncXMLFormat *)input;
 	unsigned int size;
 	char *str;
-	osync_xmlformat_assemble(xmlformat, &str, &size);
+
+	if (!osync_xmlformat_assemble(xmlformat, &str, &size, error))
+		goto error;
+
 	osync_trace(TRACE_SENSITIVE, "Input XMLFormat is:\n%s", str);
 	g_free(str);
 
@@ -163,6 +174,10 @@ static osync_bool conv_xmlformat_to_vnotememo(char *input, unsigned int inpsize,
 	osync_trace(TRACE_EXIT, "%s", __func__);
 	
 	return TRUE;
+
+error:
+	osync_trace(TRACE_EXIT_ERROR, "%s: %s", __func__, osync_error_print(error));
+	return FALSE;
 }
 
 osync_bool conv_xmlformat_to_vnote(char *input, unsigned int inpsize, char **output, unsigned int *outpsize, osync_bool *free_input, const char *config, void *userdata, OSyncError **error)
